@@ -1,4 +1,4 @@
-/* Copyright (c) 2002-2006 Sam Trenholme
+/* Copyright (c) 2002-2007 Sam Trenholme
  *
  * TERMS
  *
@@ -19,6 +19,14 @@
 #ifndef MARADNSH_DEFINED
 #define MARADNSH_DEFINED
 
+/* Some constants that are fairly OS specific, concerning the amount of
+ * memory threads can use.  These numbers should be higher than the
+ * maximum possible thread overhead */
+/* The amount of memory used to have threads at all */
+#define THREAD_OVERHEAD 536870912
+/* The amount of memory a single thread will use */
+#define PER_THREAD_MEM 16777216
+
 /* Franky Van Liedekerke's contributions so this can compile on Solaris */
 #ifdef SOLARIS
 #ifndef _uint_defined
@@ -40,19 +48,32 @@ typedef int int32_t;
 #endif /* _uint_defined */
 #endif /* MINGW32 */
 
-/* Gerrit P. Haase's suggested the following for compiling this on 
+/* Gerrit P. Haase's suggested the following for compiling this on
    Cygwin */
 #ifdef __CYGWIN__
 #define MSG_WAITALL 0x40
 #endif /* __CYGWIN__ */
 
-/* The maximum allowed size of a zone name */
-#define MAX_ZONE_SIZE 256
+/* This is the root server list as of 2007/11/15; the root servers were
+ * last changed 2007/11/01 */
+#define ROOT_SERVERS "198.41.0.4"       /* a.root-servers.net (VeriSign) */ \
+                     ",192.228.79.201"  /* b.root-servers.net (ISI) */ \
+                     ",192.33.4.12"     /* c.root-servers.net (Cogent) */ \
+                     ",128.8.10.90"     /* d.root-servers.net (UMaryland) */ \
+                     ",192.203.230.10"  /* e.root-servers.net (NASA Ames) */ \
+                     ",192.5.5.241"     /* f.root-servers.net (ISC) */ \
+                     ",192.112.36.4"    /* g.root-servers.net (DOD NIC) */ \
+                     ",128.63.2.53"     /* h.root-servers.net (ArmyRU) */ \
+                     ",192.36.148.17"   /* i.root-servers.net (NORDUnet) */ \
+                     ",192.58.128.30"   /* j.root-servers.net (VeriSign) */ \
+                     ",193.0.14.129"    /* k.root-servers.net (Reseaux) */ \
+                     ",199.7.83.42"     /* l.root-servers.net (IANA) */ \
+                     ",202.12.27.33"    /* m.root-servers.net (WIDE) */
 
-/* The default UID (User ID) that MaraDNS has; I put this here so packagers 
+/* The default UID (User ID) that MaraDNS has; I put this here so packagers
    can change this easily.  This should be the 'nobody' user, or, optionally
    a special 'MaraDNS' user.  This user needs to be able to enter
-   the /etc/maradns directory, and read all zone files in /etc/maradns 
+   the /etc/maradns directory, and read all zone files in /etc/maradns
 
    If you change this from 99, please also change the mararc man page, which
    states the default value for this is 99.  To change the man page:
@@ -62,14 +83,14 @@ typedef int int32_t;
    * Modify the mararc.ej file
 
    * Enter the doc/en/man directory
-  
-   * If you have a recent version of Perl on your system, you should be 
-     able to update the man page by typing in 'make'. 
+
+   * If you have a recent version of Perl on your system, you should be
+     able to update the man page by typing in 'make'.
 
    * Enter the doc/en/tutorial directory
 
    * Enter the doc/en/tutorial/text directory
- 
+
    * If Bash is at /bin, you should be able to update the text documentation
      by typing in make.  Otherwise, change the tools/ej/ej2txt file's first
      line to point to Bash
@@ -97,17 +118,29 @@ typedef int int32_t;
    MAN PAGE (askmara.ej) */
 #define ASKMARA_DEFAULT_SERVER "127.0.0.1"
 
-/* The port to bind the DNS server to, and the port that askmara uses 
+/* The default port to bind the DNS server to, and the port that askmara uses
    to bind to.  Note that a lot of MaraDNS' messages are hard-coded
    to say that we are binding on port 53, so only change this for
    debugging purposes.  I use this so that I can debug MaraDNS on
    systems where I do not have root. */
 #define DNS_PORT 53
 
-/* Whether we allow MaraDNS to run as a non root user; this is usually 
+/* The default port to use when contacting remove DNS servers; it may
+ * be desirable to have two instances of MaraDNS on the same IP when
+ * resolving the dangling CNAME issue on a machine with only one
+ * loopback IP (You would * think, with an entire Class A of the IP
+ * space reserved for loopback, * more systems would have at least
+ * two loopback IPs.  You would be wrong)
+ */
+#define UPSTREAM_PORT 53
+
+/* Whether we allow MaraDNS to run as a non root user; this is usually
  * disabled, but can be enabled by uncommenting the following line */
 /* #define ALLOW_NON_ROOT */
 
+/* The maximum allowed size of a zone name */
+#define MAX_ZONE_SIZE 256
+
 #ifndef JS_STRING_INCLUDED
 #include "libs/JsStr.h"
 #endif
@@ -136,7 +169,7 @@ typedef int int32_t;
 #define socklen_t int
 #endif /* MINGW32 */
 
-/* The data type used for storing "perm" bits (who gets to view a given 
+/* The data type used for storing "perm" bits (who gets to view a given
  * DNS record; based on IP) */
 #define perm_t uint16
 
@@ -151,7 +184,7 @@ typedef int int32_t;
 /* The magic "Never expire" time */
 #define NEVER_EXPIRE 0
 
-/* Structure that holds the information about either a ipv4 or ipv6 
+/* Structure that holds the information about either a ipv4 or ipv6
  * connection */
 typedef struct {
    unsigned char type; /* Type: 4 is ipv4; 6 is ipv6 */
@@ -176,9 +209,9 @@ typedef struct fila { /* Fila: Spanish for "line" */
     js_string *hash_point; /* This points to the query which generates
                               the record in question */
     char nukable_hp; /* Whether the hash point string shold be destroyed
-			when we remove this fila element. 1: Yes, nuke
-			the hash_point string; 0: No, keep the hash
-			point string */
+                        when we remove this fila element. 1: Yes, nuke
+                        the hash_point string; 0: No, keep the hash
+                        point string */
     } fila;
 
 /* DNS server that is closer to the answer for a given request */
@@ -195,7 +228,7 @@ typedef struct closer {
                               access that data when this record expires */
     struct closer *next; } closer;
 
-/* Structure which contains the data for a DNS record pointed to from 
+/* Structure which contains the data for a DNS record pointed to from
    the hash */
 typedef struct rr {
     qual_timestamp expire; /* When this RR expires (0=authoritative/never) */
@@ -207,7 +240,7 @@ typedef struct rr {
                       ip the rr domain name points to (if applicable) */
     js_string *ptr; /* If this is a PTR request pointing to a CNAME,
                        we want to give them the PTR record along
-		       with the CNAME record. */
+                       with the CNAME record. */
     uint16 rr_type; /* Type of resource record this entry is */
     js_string *query; /* Pointer to the query one asks to get this answer */
     js_string *data; /* The actual raw binary data for this RR */
@@ -216,7 +249,7 @@ typedef struct rr {
     char seen; /* This is used by udpsuccess() to insure that a given
                   element in the hash is only visited once */
     perm_t perms; /* What IPs can view this element; making this zero
-		     means that all IPs can view the element in question */
+                     means that all IPs can view the element in question */
     struct rr_list *list; /* rr_list of all records this CNAME refers to */
     char rcode; /* This is used to store the rcode for a given DNS answer */
     } rr;
@@ -234,7 +267,7 @@ typedef struct {
     uint16 id; /* 16-bit unsigned ID of Query */
     int qr; /* Boolean query-type (query or answer) */
     int opcode; /* 4-bit opcode flag */
-    int aa; /* boolean Authoritative Answer */ 
+    int aa; /* boolean Authoritative Answer */
     int tc; /* boolean truncation flag */
     int rd; /* boolean "recursion desired" flag */
     int ra; /* boolean "recursion available" flag */
@@ -263,7 +296,7 @@ typedef struct {
     js_string *rdata; /* variable length resource data */
     } q_rr;
 
-/* This is, as of June 23 2006, a list of all DNS RRs over at 
+/* This is, as of June 23 2006, a list of all DNS RRs over at
    http://www.iana.org/assignments/dns-parameters */
 /* Some query types and their RFC1035 section 3.2.2 values */
 /* A record: RFC1035 section 3.4.1 */
@@ -313,7 +346,7 @@ typedef struct {
 /* AAAA: ipv6 addresses (Not in an RFC) */
 #define RR_AAAA 28
 /* RFC1876 */
-#define RR_LOC 29 
+#define RR_LOC 29
 /* Obsolete RFC2535 and RFC3755 RR */
 #define RR_NXT 30
 /* "Endpoint" (Not in an RFC) */
@@ -324,7 +357,7 @@ typedef struct {
 #define RR_SRV 33
 /* "ATM address" (Not in an RFC) */
 #define RR_ATMA 34
-/* RFC2168,RFC2915 */
+/* RFC2168,RFC2915,RFC3403 */
 #define RR_NAPTR 35
 /* RFC2230 */
 #define RR_KX 36
@@ -337,7 +370,7 @@ typedef struct {
 /* Kitchen Sink RR (Not in an RFC; looks to be a joke but BIND supports it) */
 #define RR_SINK 40
 /* RFC2671 */
-#define RR_OPT 41 
+#define RR_OPT 41
 /* RFC3123 */
 #define RR_APL 42
 /* RFC3658 */
@@ -387,8 +420,8 @@ typedef struct {
  * make the first "dot" an at */
 #define RR_MAGIC_EMAIL -301
 
-/* The following formats use a single domain name as the data: 
-   NS CNAME PTR (MB MD MF MG) 
+/* The following formats use a single domain name as the data:
+   NS CNAME PTR (MB MD MF MG)
 */
 #define rr_ns *js_string
 #define rr_cname *js_string
@@ -402,15 +435,15 @@ typedef struct {
 /* SOA: RFC1035 3.3.13 */
 typedef struct {
     js_string *mname; /* The name server with authoritative data */
-    js_string *rname; /* Domain-name style data: email address */ 
+    js_string *rname; /* Domain-name style data: email address */
     uint32 serial; /* 32-bit serial */
     int32 refresh; /* How often slave servers look at the serial to
                     see if it should be refreshed */
     int32 retry; /* How often slave servers should look at the serial when
                   the server is down */
     int32 expire; /* How long before the slave servers "give up" on looking
-                   at data from the master server when the master server 
-		   dies */
+                   at data from the master server when the master server
+                   dies */
     uint32 minimum; /* Default TTL for all RRs in the zone */
     } rr_soa;
 
@@ -434,7 +467,7 @@ typedef struct {
 
 /* The longest RRs which we allow to exist in csv1 zone files.
    Warning: If you make this longer, then there is a significant
-   risk that the record will be longer than the 512 bytes allowed 
+   risk that the record will be longer than the 512 bytes allowed
    in a DNS packet.  MaraDNS does not current support DNS over TCP.
 */
 
