@@ -581,8 +581,12 @@ int js_read(js_file *desc, js_string *js, int count) {
     if(count % js->unit_size != 0)
         return JS_ERROR;
 #ifndef MINGW32
-    if(count < 0 || count > SSIZE_MAX)
+    if(count < 0 || count > 1048576)
         return JS_ERROR;
+#if (SSIZE_MAX < 1048576)
+    if(count > SSIZE_MAX)
+        return JS_ERROR;
+#endif /* SSIZE_MAX small */
 #else
     if(count < 0 || count > 1024)
         return JS_ERROR;
@@ -625,8 +629,12 @@ int js_write(js_file *desc, js_string *js) {
 
     to_write = js->unit_size * js->unit_count;
 #ifndef MINGW32
-    if(to_write < 0 || to_write > SSIZE_MAX)
+    if(to_write < 0 || to_write > 1048576)
         return JS_ERROR;
+#if (SSIZE_MAX < 1048576)
+    if(to_write > SSIZE_MAX)
+        return JS_ERROR;
+#endif /* SSIZE_MAX small */
 #else
     if(to_write < 0 || to_write > 1024)
         return JS_ERROR;
