@@ -21,8 +21,8 @@
 /* --- MaraBigHash.c --- */
 
 int starrecord_to_meta(js_string *rr, int recursive);
-int add_rr_to_bighash(mhash *bighash, js_string *query, 
-		js_string *data, uint32 ttl, js_string *zone, perm_t perms);
+int add_rr_to_bighash(mhash *bighash, js_string *query,
+                js_string *data, uint32 ttl, js_string *zone, perm_t perms);
 
 /* --- MaraDNS.c --- */
 int fold_case(js_string *js);
@@ -52,12 +52,12 @@ csv2_add_state *csv2_init_add_state(js_string *zone);
  * x is using up */
 void csv2_zap_add_state(csv2_add_state *x);
 
-/* Function to set the big hash we point to 
+/* Function to set the big hash we point to
  * Input: Pointer to hash
  * Output: JS_ERROR on error; JS_SUCCESS on success */
 int csv2_set_bighash(csv2_add_state *state, mhash *bighash);
 
-/* Function to set the method we use to process sucessfully parsed 
+/* Function to set the method we use to process sucessfully parsed
  * records.  Input: numeric method process
  * Output: JS_ERROR on error, JS_SUCCESS on success */
 int csv2_set_add_method(csv2_add_state *state, int method);
@@ -77,8 +77,8 @@ int csv2_set_soa_serial(csv2_add_state *state, js_string *filename);
 js_string *csv2_zone_to_udpzone(js_string *zone);
 
 /* Function that just shows the rr we would have added; this is mainly
- * for debugging purposes 
- * Input: The csv2_add_state, the query (Blabel), 
+ * for debugging purposes
+ * Input: The csv2_add_state, the query (Blabel),
  * the rtype, the ttl, and the data.
  * Output: JS_ERROR on error, JS_SUCCESS on success
  */
@@ -86,8 +86,8 @@ js_string *csv2_zone_to_udpzone(js_string *zone);
 int csv2_add_rr_debug(csv2_add_state *state, js_string *query,
                 int rtype, int32 ttl, js_string *data);
 
-/* Function to add an rr to the big hash; 
- * Input: The csv2_add_state, 
+/* Function to add an rr to the big hash;
+ * Input: The csv2_add_state,
  * the query (Blabel), the rtype, the ttl, and the data.
  * Output: JS_ERROR on error; JS_SUCCESS on success
  */
@@ -95,13 +95,13 @@ int csv2_add_rr_debug(csv2_add_state *state, js_string *query,
 int csv2_add_rr_bighash(csv2_add_state *state, js_string *query,
                 int rtype, int32 ttl, js_string *data, int32 starwhitis);
 
-/* Function to process an rr for the zone server; 
- * Input: The csv2_add_state, 
+/* Function to process an rr for the zone server;
+ * Input: The csv2_add_state,
  * the query (Blabel), the rtype, the ttl, and the data.
  * Output: JS_ERROR on error; JS_SUCCESS on success
  */
 
-int csv2_add_rr_zoneserver(csv2_add_state *state, js_string *query, 
+int csv2_add_rr_zoneserver(csv2_add_state *state, js_string *query,
                 int rtype, int32 ttl, js_string *data);
 
 /* Create a synthetic query
@@ -118,7 +118,7 @@ int csv2_synthesize_soa(csv2_add_state *state);
  *        we actually make the record (1) or just the blabel (0)
  * Output: The Blabel with the record in question.
  */
-js_string *csv2_synth_ip(csv2_add_state *state, uint32 ip, 
+js_string *csv2_synth_ip(csv2_add_state *state, uint32 ip,
                 int actually_make_record);
 
 /* Make a single synthetic NS record */
@@ -129,7 +129,7 @@ int csv2_make_synth_ns(csv2_add_state *state, uint32 ip);
  * 1: Yes, we're are looking at one */
 int csv2_is_private_ip(uint32 ip);
 
-/* tell us if we are looking at a localhost IP 
+/* tell us if we are looking at a localhost IP
  * 0: Nope
  * 1: yep */
 int csv2_is_localhost_ip(uint32 ip);
@@ -146,15 +146,15 @@ csv2_rr *copy_csv2_rr(csv2_rr *source);
  * Input: The query, rtype, etc. of what we will add.
  * Output: JS_ERROR on error, JS_SUCCESS on success */
 int csv2_push_buffer(csv2_add_state *state, js_string *query, int rtype,
-		                int32 ttl, js_string *data);
-		                
+                                int32 ttl, js_string *data);
+
 /* Get the soa in a state.
  * Input: The raw js_string query and data; the ttl
  * Output: JS_ERROR on error; JS_SUCCESS on success */
 
 int csv2_set_soa(csv2_add_state *state, js_string *query, js_string *data,
                 int32 ttl);
-/* Check to see if the query is the same as the zone in state 
+/* Check to see if the query is the same as the zone in state
  * Input: the state, a query
  * Output: 1 if they are the same, 0 otherwise */
 int csv2_is_zonetop(csv2_add_state *state, js_string *query);
@@ -197,13 +197,13 @@ int csv2_is_hash(int32 in);
 
 /* --- Csv2_main.c --- */
 
-/* The main function for parsing a csv2_zone for putting stuff 
+/* The main function for parsing a csv2_zone for putting stuff
  * in the big hash */
 int csv2_parse_main_bighash(mhash *main_table, int32 starwhitis);
 
 /* The function we call from the zoneserver; this lets us put the contents
  * of the zone in question available over the TCP socket specified by
- * the calling program (zoneserver) 
+ * the calling program (zoneserver)
  * Input: The name of the zone (example.com., etc.) in Alabel format
  *        The name of the file with the zone
  *        The tcp connection socket (connect)
@@ -218,57 +218,57 @@ int csv2_parse_zone_zoneserver(js_string *zone,
 /* The following was semi-automatically generated */
 
 js_string *process_1stchar(csv2_read *stream, int (*is_ok)(int32 in),
-		char *pre);
-int csv2_parse_zone_bighash(js_string *zone, js_string *filename, 
-		mhash *bighash, int32 starwhitis); 
+                char *pre);
+int csv2_parse_zone_bighash(js_string *zone, js_string *filename,
+                mhash *bighash, int32 starwhitis);
 int csv2_parse_zone(js_string *filename, csv2_add_state *state,
-		int32 starwhitis);
-int csv2_see_char(int32 in, char *list); 
-int csv2_is_number(int32 in); 
-int csv2_is_upper(int32 in); 
-int csv2_is_lower(int32 in); 
-int csv2_is_hibit(int32 in); 
-int csv2_is_delimiter(int in); 
-int32 csv2_get_utf8(csv2_read *stream); 
-int32 csv2_read_unicode(csv2_read *stream); 
-int csv2_append_utf8(js_string *toappend, int32 in); 
+                int32 starwhitis);
+int csv2_see_char(int32 in, char *list);
+int csv2_is_number(int32 in);
+int csv2_is_upper(int32 in);
+int csv2_is_lower(int32 in);
+int csv2_is_hibit(int32 in);
+int csv2_is_delimiter(int in);
+int32 csv2_get_utf8(csv2_read *stream);
+int32 csv2_read_unicode(csv2_read *stream);
+int csv2_append_utf8(js_string *toappend, int32 in);
 int csv2_get_1st(csv2_read *stream, int (*is_ok)(int32 in), int options);
-int csv2_is_alpha(int32 in); 
-int csv2_is_alphanum(int32 in); 
-int csv2_is_text(int32 in); 
+int csv2_is_alpha(int32 in);
+int csv2_is_alphanum(int32 in);
+int csv2_is_text(int32 in);
 int csv2_is_dchar(int32 in);
-int csv2_is_starwhitis(int32 in); 
-int csv2_numeric_rtype(js_string *text_rtype); 
-int32 csv2_get_rtype(csv2_read *stream); 
-int32 csv2_get_num(csv2_read *stream); 
+int csv2_is_starwhitis(int32 in);
+int csv2_numeric_rtype(js_string *text_rtype);
+int32 csv2_get_rtype(csv2_read *stream);
+int32 csv2_get_num(csv2_read *stream);
 int csv2_read_rr(csv2_add_state *state, csv2_read *stream, int32 starwhitis);
-void process_comment(csv2_read *stream); 
+void process_comment(csv2_read *stream);
 js_string *process_something(csv2_read *stream, int (*is_ok)(int32 in));
-js_string *process_number(csv2_read *stream); 
-js_string *process_textlabel(csv2_read *stream); 
-js_string *process_dname(csv2_read *stream, int starwhitis); 
-js_string *js_append_dname(js_string *o, csv2_read *stream, int starwhitis); 
+js_string *process_number(csv2_read *stream);
+js_string *process_textlabel(csv2_read *stream);
+js_string *process_dname(csv2_read *stream, int starwhitis);
+js_string *js_append_dname(js_string *o, csv2_read *stream, int starwhitis);
 js_string *csv2_get_hostname(csv2_read *stream, js_string *zonename,
-		int starwhitis); 
-js_string *csv2_get_dname(csv2_read *stream); 
-js_string *csv2_get_soa(csv2_read *stream, js_string *zone, 
-	csv2_add_state *state);
+                int starwhitis);
+js_string *csv2_get_dname(csv2_read *stream);
+js_string *csv2_get_soa(csv2_read *stream, js_string *zone,
+        csv2_add_state *state);
 js_string *csv2_convert_percent(js_string *in, js_string *psub);
-int csv2_close(csv2_read *file); 
-int csv2_readchar(csv2_read *file); 
-int csv2_justread(csv2_read *file); 
-int csv2_error(csv2_read *file, char *why); 
-int32 csv2_get_unicode(csv2_read *file); 
-int csv2_set_unicode(csv2_read *file, int32 in); 
-csv2_read *csv2_open(js_string *filename); 
-int csv2_is_hex(int32 in); 
-int csv2_is_hex_or_colon(int32 in); 
-js_string *process_aaaa(csv2_read *stream); 
-int csv2_is_number_or_dot(int32 in); 
-js_string *process_ipv4_ddip(csv2_read *stream); 
-js_string *csv2_get_a(csv2_read *stream); 
-int csv2_b4_at(int32 in); 
-js_string *process_mbox(csv2_read *stream); 
+int csv2_close(csv2_read *file);
+int csv2_readchar(csv2_read *file);
+int csv2_justread(csv2_read *file);
+int csv2_error(csv2_read *file, char *why);
+int32 csv2_get_unicode(csv2_read *file);
+int csv2_set_unicode(csv2_read *file, int32 in);
+csv2_read *csv2_open(js_string *filename);
+int csv2_is_hex(int32 in);
+int csv2_is_hex_or_colon(int32 in);
+js_string *process_aaaa(csv2_read *stream);
+int csv2_is_number_or_dot(int32 in);
+js_string *process_ipv4_ddip(csv2_read *stream);
+js_string *csv2_get_a(csv2_read *stream);
+int csv2_b4_at(int32 in);
+js_string *process_mbox(csv2_read *stream);
 
 csv2_add_state *csv2_init_add_state(js_string *zone);
 
@@ -287,3 +287,10 @@ js_string *csv2_get_loc(csv2_read *stream);
 /* Some more Csv2_read.c functions */
 int csv2_push_file(csv2_read *file, js_string *filename);
 int csv2_pop_file(csv2_read *file);
+void csv2_allow_tilde(csv2_read *file);
+void csv2_forbid_tilde(csv2_read *file);
+void csv2_allow_leftbrace(csv2_read *file);
+void csv2_forbid_leftbrace(csv2_read *file);
+int csv2_tilde_seen(csv2_read *file);
+void csv2_reset_tilde_seen(csv2_read *file);
+
