@@ -1,4 +1,4 @@
-/* Copyright (c) 2002-2006 Sam Trenholme and Albert Lee
+/* Copyright (c) 2002-2007 Sam Trenholme and Albert Lee
  *
  * TERMS
  *
@@ -34,7 +34,7 @@
 #include <errno.h>
 #include <string.h>
 #include <time.h>
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) || defined(__DragonFly__)
 #include <sys/time.h>
 #endif
 #include <sys/types.h>
@@ -65,6 +65,13 @@
 int num_children = 0;
 /* Another global variable: How many times they have run srng() before */
 int srng_place = 0;
+/* Yet another global variable: How csv2 zone files handle the tilde
+ * character */
+int csv2_tilde_handling = 2;
+/* And another global variable: How much logging we do */
+int verbose = 0;
+/* Placeholder; dns_records_served is used by MaraDNS.c */
+int dns_records_served = 0;
 /* The last global variable: The IP of the UDP server we forward queries
    to */
 int udp_forward_server = 0;
@@ -77,6 +84,12 @@ void handle_childs() {
         num_children--;
 }
 
+/* Signal handler for termination of the root process */
+void handle_term() {
+    killpg(getpgrp(), SIGTERM);
+    exit(0);
+}
+
 /* Print out log messages
    Input: Null-terminated string with the message to log
    Output: JS_SUCCESS on success, JS_ERROR on error
@@ -98,6 +111,7 @@ int mlog(char *logmessage) {
 
 void harderror(char *why) {
     printf("%s%s%s",L_FATAL,why,LF); /* "Fatal error: ", why, "\n" */
+    killpg(getpgrp(), SIGTERM); /* Don't leave orphaned children */
     exit(3);
     }
 
@@ -143,13 +157,13 @@ uint16 srng() {
                so that old mararc files work with the new zoneserver */
             }
 
-	/* Default random_seed_file: /dev/urandom */
-	if(js_length(srng_filename) == 0) {
-		if(js_qstr2js(srng_filename,"/dev/urandom") != JS_SUCCESS) {
-			printf("AIEEEE! Can not set default random_seed_file");
-			exit(1);
-			}
-		}
+        /* Default random_seed_file: /dev/urandom */
+        if(js_length(srng_filename) == 0) {
+                if(js_qstr2js(srng_filename,"/dev/urandom") != JS_SUCCESS) {
+                        printf("AIEEEE! Can not set default random_seed_file");
+                        exit(1);
+                        }
+                }
 
         /* OK, now start doing the RNG stuff */
         memset(r_inBlock,0,16);
@@ -246,8 +260,8 @@ int tcpbind(int *sock, uint32 ip) {
     /* Sanity checks */
     if(sock == 0)
         return JS_ERROR;
-    if(ip == 0xffffffff) 
-	return JS_ERROR;
+    if(ip == 0xffffffff)
+        return JS_ERROR;
 
     /* This will convert ip into the correct form */
     ip = htonl(ip);
@@ -268,9 +282,9 @@ int tcpbind(int *sock, uint32 ip) {
 
     /* Bind to the socket.  Note that we usually have to be root to do this */
     if(bind(*sock,(struct sockaddr *)&dns_tcp,len_inet) == -1) {
-	printf("Unable to bind to to IP: ");
-	printf("%s",strerror(errno));
-	printf("\n");
+        printf("Unable to bind to to IP: ");
+        printf("%s",strerror(errno));
+        printf("\n");
         return JS_ERROR;
     }
 
@@ -341,6 +355,13 @@ int gettcp(int *sock, ipv4pair *acl1, ipv4pair *acl2, ipv4pair *acl3,
         /* OK, they were not on the ACL list.  Clise the connection and
            return an error */
         close(ret);
+        if(verbose >= 4) {
+                printf("Failed zone transfer attempt from IP %d.%d.%d.%d\n",
+                ip >> 24,
+                (ip >> 16) & 0xff,
+                (ip >> 8) & 0xff,
+                ip & 0xff);
+                }
         return JS_ERROR;
         }
     else {
@@ -629,7 +650,7 @@ int serve_zone(int connect, int perms) {
         goto clean_nd;
         }
 
-    /* If they only have permission to convert (proxy via UDP) the query, 
+    /* If they only have permission to convert (proxy via UDP) the query,
        do so */
     if((perms & 1) != 1) {
         if((perms & 2) == 2) {
@@ -688,13 +709,13 @@ int serve_zone(int connect, int perms) {
     if(js_copy(name,binzone) == JS_ERROR) {
         goto clean_ndb;
         }
-    /* Convert the name in to all lowercase (since A-Z never appear as a 
+    /* Convert the name in to all lowercase (since A-Z never appear as a
        metacharacter in a zone file, we can quickly do this conversion) */
     for(counter = 0; counter < name->unit_count; counter++) {
         if(*(name->string + counter) >= 'A' &&
            *(name->string + counter) <= 'Z') {
               *(name->string + counter) += 32;
-              } 
+              }
         }
     /* Convert the name in to a dotted decimal format that the mararc
        file uses */
@@ -710,13 +731,13 @@ int serve_zone(int connect, int perms) {
      * zones over slow links) */
     alarm(0);
     if(read_dvar(name,data,name) == JS_ERROR) { /* XXX Covers "no such zone" */
-	    /* If we don't have a csv1 zone, perhaps we have a csv2 zone;
-	     * check in csv2_parse_zone_zoneserver */
-	    if(csv2_parse_zone_zoneserver(data,connect,soa_q,&header) ==
-			    JS_SUCCESS) {
-		    /* Success; close the connection, etc. */
-		    exit(0); /* fork() makes all that easy :) */
-	    }
+            /* If we don't have a csv1 zone, perhaps we have a csv2 zone;
+             * check in csv2_parse_zone_zoneserver */
+            if(csv2_parse_zone_zoneserver(data,connect,soa_q,&header) ==
+                            JS_SUCCESS) {
+                    /* Success; close the connection, etc. */
+                    exit(0); /* fork() makes all that easy :) */
+            }
             mlog(L_NO_ZONE_HERE); /* "Zone we do not have asked for, disconnecting" */
             goto clean_ndb;
     }
@@ -979,7 +1000,7 @@ int main(int argc, char **argv) {
     js_string *mararc_loc, *errors, *chrootn, *kvar_str, *maxpstr,
               *kvar_query, *bind_address, *incoming, *uncomp, *verbstr;
     unsigned char chroot_zt[255];
-    int errorn, sock, maxprocs, verbose, counter, connection,
+    int errorn, sock, maxprocs, counter, connection,
         inetd = 0;
 #ifndef DARWIN
     struct rlimit rlim;
@@ -992,6 +1013,13 @@ int main(int argc, char **argv) {
     int synth_soa_serial;
     js_string *synth_soa_origin;
 
+    /* Kill children processes when we are signaled */
+    if(setpgrp()) {
+        printf(strerror(errno)); /* harderror() would kill the group which may not be correct yet */
+        return 3;
+    }
+    signal(SIGTERM,handle_term);
+
     /* Initialize the strings (allocate memory for them, etc.) */
     if((mararc_loc = js_create(256,1)) == 0)
         harderror(L_MLC); /* "Could not create mararc_loc string" */
@@ -1074,6 +1102,14 @@ on %s\nFor usage information, type in 'man maradns'" */
     /* Limit the maximum number of processes */
     maxprocs = read_numeric_kvar("maxprocs",128);
 
+    /* Determine how csv2 zone files will handle the tilde character */
+    csv2_tilde_handling = read_numeric_kvar("csv2_tilde_handling",2);
+    if(csv2_tilde_handling < 0 || csv2_tilde_handling > 3) {
+        harderror("csv2_tilde_handling "
+                  "must have a value between 0 and 3");
+        exit(1);
+        }
+
     /* If we have both maxprocs and max_tcp_procs defined, the zone server
        will use max_tcp_procs. */
     if(js_qstr2js(kvar_query,"max_tcp_procs") == JS_ERROR)
@@ -1114,12 +1150,12 @@ on %s\nFor usage information, type in 'man maradns'" */
         if(chroot((char *)chroot_zt) != 0)
             harderror(L_CHROOT_ERROR);  /* "Problem changing the root directory." */
 
-	
-	/* Determine which uid and gid to use */
-	uid = read_numeric_kvar("maradns_uid",MARADNS_DEFAULT_UID);
-	gid = read_numeric_kvar("maradns_gid",MARADNS_DEFAULT_GID);
+
+        /* Determine which uid and gid to use */
+        uid = read_numeric_kvar("maradns_uid",MARADNS_DEFAULT_UID);
+        gid = read_numeric_kvar("maradns_gid",MARADNS_DEFAULT_GID);
         if(uid < 10)  /* Security check */
-	      uid = MARADNS_DEFAULT_UID;	
+              uid = MARADNS_DEFAULT_UID;
 
         mlog(L_CHROOT_SUCCESS); /* "Root directory changed" */
 
@@ -1129,99 +1165,101 @@ on %s\nFor usage information, type in 'man maradns'" */
         */
         if(inetd != 1) { /* If we are a standalone server */
             ipv4pair *bind_addresses;
-	    int bind_address_iterate;
-	    int stream1[2]; /* Used for piping */
-	    /* pid_t child[70]; */ /* Children's process IDs */
+            int bind_address_iterate;
+            int stream1[2]; /* Used for piping */
+            /* pid_t child[70]; */ /* Children's process IDs */
 
-	    /* bind_address is now a js_string object in the
-	     * form "10.1.2.3,10.1.2.4".  Use the make_ip_acl code to
-	     * make a list of bind addresses from the bind_address string,
-	     * then fork once for each bind address.  This will
-	     * be somewhat like the code below that gets the zone transfer
-	     * ACL list
-	     * */
+            /* bind_address is now a js_string object in the
+             * form "10.1.2.3,10.1.2.4".  Use the make_ip_acl code to
+             * make a list of bind addresses from the bind_address string,
+             * then fork once for each bind address.  This will
+             * be somewhat like the code below that gets the zone transfer
+             * ACL list
+             * */
 
-	    bind_addresses = libtcp_bind_address(1);
-	    if(bind_addresses == 0 || bind_addresses[0].ip == 0xffffffff) {
-		    harderror("Could not make list of bind addresses");
-	    }
-	    bind_address_iterate = 0;
-	    while(bind_address_iterate < 70 && 
-		    bind_addresses[bind_address_iterate].ip != 0xffffffff) {
-		    /* Spawn a child process that is only bound to this
-		     * IP */
-		    /* We set things up so the
-		     * child's stdout/stderr goes to the parent's
-		     * stdout/stderr */
-		    if(pipe(stream1) != 0) 
-			    harderror("Pipe()'s broken");
-		    /* if((child[bind_address_iterate] = fork())) { * Parent */
-		    if((pid = fork())) { /* Parent */
-			    close(stream1[1]);
-			    fcntl(stream1[0],F_SETFL,O_NONBLOCK);
-			    /* The following might not be portable */
-			    if(stream1[0] != bind_address_iterate + 3)
-			        dup2(stream1[0],
-			       bind_address_iterate + 3); /* Pipe redirected */
-		    } else { /* Child */
-			    close(stream1[0]);
-			    dup2(stream1[1],1); /* Stdout redirected to pipe */
-			    dup2(stream1[1],2); /* Stderr redirection */
+            bind_addresses = libtcp_bind_address(1);
+            if(bind_addresses == 0 || bind_addresses[0].ip == 0xffffffff) {
+                    harderror("Could not make list of bind addresses");
+            }
+            bind_address_iterate = 0;
+            while(bind_address_iterate < 70 &&
+                    bind_addresses[bind_address_iterate].ip != 0xffffffff) {
+                    /* Spawn a child process that is only bound to this
+                     * IP */
+                    /* We set things up so the
+                     * child's stdout/stderr goes to the parent's
+                     * stdout/stderr */
+                    if(pipe(stream1) != 0)
+                            harderror("Pipe()'s broken");
+                    /* if((child[bind_address_iterate] = fork())) { * Parent */
+                    if((pid = fork())) { /* Parent or error */
+                    if(pid < 0)
+                        harderror("Could not fork");
+                            close(stream1[1]);
+                            fcntl(stream1[0],F_SETFL,O_NONBLOCK);
+                            /* The following might not be portable */
+                            if(stream1[0] != bind_address_iterate + 3)
+                                dup2(stream1[0],
+                               bind_address_iterate + 3); /* Pipe redirected */
+                    } else { /* Child */
+                            close(stream1[0]);
+                            dup2(stream1[1],1); /* Stdout redirected to pipe */
+                            dup2(stream1[1],2); /* Stderr redirection */
                             if(tcpbind(&sock,
-		        bind_addresses[bind_address_iterate].ip) == JS_ERROR)
+                        bind_addresses[bind_address_iterate].ip) == JS_ERROR)
                             harderror(L_BIND); /* "Problem binding to port 53.\nMost likely, another process is already listening on port 53" */
-			    break;
-		    }
-		    bind_address_iterate++;
-	    }
-	    if(pid) { /* Parent */
-		    /* Handle children's output */
-		    fd_set child_set;
-		    fd_set read_set;
-		    char buf[1024];
-		    ssize_t readed;
-		    setgid(gid);
-		    if(setuid(uid) != 0) {
-			    harderror("Parent couldn't drop UID\n");
-		    }
-		    FD_ZERO(&child_set);
-		    /* Add all child fds */
-		    for(counter = 3;
-		      counter < bind_address_iterate + 3; counter++) {
-		        FD_SET(counter,&child_set);
-		    }
-		    for(;;) {
-			    FD_ZERO(&read_set);
-			    /* select on available children */
-			    for(counter = 3;
-			      counter < bind_address_iterate + 3; counter++) {
-			        if(FD_ISSET(counter,&child_set))
-			            FD_SET(counter,&read_set);
-			    }
-			    if(select(bind_address_iterate + 3,&read_set,
-			      NULL,NULL,NULL) > 0) {
-			        for(counter = 3;
-			          counter < bind_address_iterate + 3; counter++) {
-			            if(FD_ISSET(counter,&read_set)) {
-			                readed = read(counter,buf,1024);
-			                if(readed > 0) {
-			                    write(1,buf,readed);	    
-			                } else {
-			                    /* No longer exists  */
-			                    close(counter);
-			                    FD_CLR(counter,&child_set);
-			                }
-			            }
-			        }
-			    } else {
-			        break;
-			    }
-			    waitpid(0,NULL,WNOHANG); /* Catch exited children */
-		    }
-		    return 0;
-	    }
-	    if(libtcp_create_bind_addrs() == JS_ERROR) 
-		harderror("libtcp_create_synthip_addrs");
+                            break;
+                    }
+                    bind_address_iterate++;
+            }
+            if(pid) { /* Parent */
+                    /* Handle children's output */
+                    fd_set child_set;
+                    fd_set read_set;
+                    char buf[1024];
+                    ssize_t readed;
+                    setgid(gid);
+                    if(setuid(uid) != 0) {
+                            harderror("Parent couldn't drop UID\n");
+                    }
+                    FD_ZERO(&child_set);
+                    /* Add all child fds */
+                    for(counter = 3;
+                      counter < bind_address_iterate + 3; counter++) {
+                        FD_SET(counter,&child_set);
+                    }
+                    for(;;) {
+                            FD_ZERO(&read_set);
+                            /* select on available children */
+                            for(counter = 3;
+                              counter < bind_address_iterate + 3; counter++) {
+                                if(FD_ISSET(counter,&child_set))
+                                    FD_SET(counter,&read_set);
+                            }
+                            if(select(bind_address_iterate + 3,&read_set,
+                              NULL,NULL,NULL) > 0) {
+                                for(counter = 3;
+                                  counter < bind_address_iterate + 3; counter++) {
+                                    if(FD_ISSET(counter,&read_set)) {
+                                        readed = read(counter,buf,1024);
+                                        if(readed > 0) {
+                                            write(1,buf,readed);
+                                        } else {
+                                            /* No longer exists  */
+                                            close(counter);
+                                            FD_CLR(counter,&child_set);
+                                        }
+                                    }
+                                }
+                            } else {
+                                break;
+                            }
+                            waitpid(0,NULL,WNOHANG); /* Catch exited children */
+                    }
+                    return 0;
+            }
+            if(libtcp_create_bind_addrs() == JS_ERROR)
+                harderror("libtcp_create_synthip_addrs");
             mlog(L_SOCKET_SUCCESS);  /* "Socket opened on TCP port 53" */
             }
 
@@ -1237,7 +1275,7 @@ on %s\nFor usage information, type in 'man maradns'" */
 
         }
     else {
-	harderror("inetd is not zero; this is a fatal error.  Complain loudly on the MaraDNS\nmailing list.\n");
+        harderror("inetd is not zero; this is a fatal error.  Complain loudly on the MaraDNS\nmailing list.\n");
         }
 
     /* Make a database of IPs permitted to transfer zone file */
@@ -1249,12 +1287,12 @@ on %s\nFor usage information, type in 'man maradns'" */
     if(read_kvar(kvar_query,kvar_str) == JS_ERROR)
         harderror(L_NO_ACL); /* "Could not read zone_transfer_acl data" */
     if(inetd == 1) {
-	harderror("inetd is set.  This is a fatal error.  You should not be seeing this\nComplain loudly on the MaraDNS mailing list.");
+        harderror("inetd is set.  This is a fatal error.  You should not be seeing this\nComplain loudly on the MaraDNS mailing list.");
         }
     else {
         if(make_ip_acl(kvar_str,zonetransfer_acl,500,0) == JS_ERROR) {
             /* harderror(L_ACL_LIST); *//* "Could not make ip ACL list" */
-	    zonetransfer_acl[0].ip=0xffffffff; /* No zone transfer ACL */
+            zonetransfer_acl[0].ip=0xffffffff; /* No zone transfer ACL */
             }
         }
 
@@ -1328,7 +1366,7 @@ on %s\nFor usage information, type in 'man maradns'" */
         harderror("Fatal: synth_soa_serial must be 1 or 2\n");
         }
     set_soa_serial(synth_soa_serial);
-    verbstr = read_string_kvar("synth_soa_origin"); 
+    verbstr = read_string_kvar("synth_soa_origin");
     if(verbstr != 0 && js_length(verbstr) > 0) {
         synth_soa_origin = js_create(256,1);
         if(synth_soa_origin == 0) {
@@ -1410,8 +1448,8 @@ on %s\nFor usage information, type in 'man maradns'" */
            the program */
         while(waitpid(0,NULL,WNOHANG) > 0) num_children--;
 
-	/* Make sure to close any lingering open connections */
-	close(connection);
+        /* Make sure to close any lingering open connections */
+        close(connection);
         }
 
     }
