@@ -45,7 +45,7 @@
 #include "../dns/functions_dns.h"
 #include "../parse/functions_parse.h"
 
-int verbose_mode = 0; /* Whether to have short or verbose output; 
+int verbose_mode = 0; /* Whether to have short or verbose output;
                          1: verbose output; any other value: short output */
 int timeout = 21;
 
@@ -72,12 +72,12 @@ int escape_stdout(js_string *js) {
 
     while(counter < js->unit_count) {
         this = *(js->string + counter);
-	if(this < 32 || this > 126) 
-	    printf("\\%03o",this);
-        else if(this == '\\') 
-	    printf("\\%c",this);
+        if(this < 32 || this > 126)
+            printf("\\%03o",this);
+        else if(this == '\\')
+            printf("\\%c",this);
         else
-	    printf("%c",this);
+            printf("%c",this);
         counter++;
         }
     return 1;
@@ -104,28 +104,28 @@ u_int16_t gen_id(char *hostname) {
 
     /* Initialize the keys, including the "binKey" (is this used?) */
     memset(r_binKey,'0',16);
-    mc1 = "ñ";
+    mc1 = "";
     mc2 = mc1;
-    /* Set the crypto key to 'ññññññññññññññññ' (UTF-8 encoding) */
+    /* Set the crypto key to '' (UTF-8 encoding) */
     for(counter = 0; counter < 16; counter++) {
         *(crypto_key + counter) = *mc2;
-	mc2++;
-	if(*mc2 == 0) 
-	   mc2 = mc1;
+        mc2++;
+        if(*mc2 == 0)
+           mc2 = mc1;
         }
-    /*memset(crypto_key,'ñ',16);*/
+    /*memset(crypto_key,'',16);*/
     /* Make the first 16 characters of the hostname the key (padded by the
-       ñ character--do you see a n~ there?) */
+        character--do you see a n~ there?) */
     strncpy((char *)crypto_key,hostname,16);
-    /* Set the plaintext block to 'ññññññññññññññññ' (UTF-8 encoding) */
+    /* Set the plaintext block to '' (UTF-8 encoding) */
     mc2 = mc1;
     for(counter = 0; counter < 16; counter++) {
         *(r_inBlock + counter) = *mc2;
-	mc2++;
-	if(*mc2 == 0) 
-	   mc2 = mc1;
+        mc2++;
+        if(*mc2 == 0)
+           mc2 = mc1;
         }
-    /*memset(r_inBlock,'ñ',16);*/
+    /*memset(r_inBlock,'',16);*/
     /* If the hostname is longer than 16 characters, make the plaintext
        the longer part of the hostname */
     if(strlen(hostname) > 16)
@@ -181,13 +181,13 @@ int main(int argc, char **argv) {
 
     /* See if we should allow a user defined timeout or not */
     timeout = 31;
-    if(argc >= 4 + nrd && *argv[1 + nrd] == '-' && *(argv[1 + nrd] + 1) == 
+    if(argc >= 4 + nrd && *argv[1 + nrd] == '-' && *(argv[1 + nrd] + 1) ==
        't') {
          timeout = atoi(argv[2 + nrd]);
-	 verbose_mode = 2;
-	 }
+         verbose_mode = 2;
+         }
 
-    if(timeout < 1) 
+    if(timeout < 1)
         harderror(L_INVALID_TIMEOUT);
 
     /* Determine what IP address to connect to */
@@ -264,16 +264,16 @@ int main(int argc, char **argv) {
 
     do {
         /* Connect to the zone server */
-	if(connect(s,(struct sockaddr *)&server,len_inet) == -1)
-	/* Determine how long it is */
-	printf("DEBUG: outdata->unit_count %d\n",outdata->unit_count);
-	len[0] = (outdata->unit_count & 0xff00) >> 8;
-	len[1] = outdata->unit_count & 0xff;
+        if(connect(s,(struct sockaddr *)&server,len_inet) == -1)
+        /* Determine how long it is */
+        printf("DEBUG: outdata->unit_count %d\n",outdata->unit_count);
+        len[0] = (outdata->unit_count & 0xff00) >> 8;
+        len[1] = outdata->unit_count & 0xff;
 
         /* Send out how long the request is */
-	if(write(s,len,2) == -1) {
-	    harderror("XXX No error message yet 271");
-	    }
+        if(write(s,len,2) == -1) {
+            harderror("XXX No error message yet 271");
+            }
 
         /* Send out a DNS request */
         if(write(s,outdata->string,outdata->unit_count) == -1)
@@ -281,31 +281,31 @@ int main(int argc, char **argv) {
 
         /* Wait for a reply from the DNS server */
         recv(s,len,2,MSG_WAITALL);
-	length = ((len[0] << 8) & 0xff00) | (len[1] & 0xff);
+        length = ((len[0] << 8) & 0xff00) | (len[1] & 0xff);
         if(length < 12)
-	    harderror("XXX No error message yet 282");
+            harderror("XXX No error message yet 282");
         if((count = recv(s,indata->string,length,MSG_WAITALL)) < 0)
             harderror(L_DNS_R_ERROR); /* Problem getting DNS server response */
 
         if(count != length)
-	     harderror("Length of reply not same as stated length");
+             harderror("Length of reply not same as stated length");
 
         indata->unit_count = count;
 
         /* Get the ID from the remote response */
         if(count > 2) {
-	   id = (*(indata->string) << 8) | *(indata->string + 1);
-	   }
+           id = (*(indata->string) << 8) | *(indata->string + 1);
+           }
         else {
-	   id = header.id + 1;
-	   }
+           id = header.id + 1;
+           }
 
         printf("DEBUG ID: %d header.id: %d\n",id,header.id);
 
         attempts--;
 
-	/* If the id doesn't match, get a reply again */
-	} while(id != header.id && attempts > 0); 
+        /* If the id doesn't match, get a reply again */
+        } while(id != header.id && attempts > 0);
 
     decomp_init(0);
     decompress_data(indata,uindata);
@@ -484,8 +484,8 @@ int out_answer(js_string *uindata,int *place) {
 
         *place += rr_hdr.rdlength; /* To do: read the RD data itself for
                                       all MaraDNS supported RRs */
-        
-	return 0;
+
+        return 0;
         }
 
 /* csv1-compatible form of askmara output
@@ -515,10 +515,10 @@ int csv1_compatible_output(js_string *uindata, js_string *query) {
         if(count < 0) /* Error handling */
             harderror(L_QERROR); /* Error reading question */
         printf("# Question: ");
-	if(hname_translate(question.qname,question.qtype) == JS_ERROR) 
-	    harderror(L_QERROR);
+        if(hname_translate(question.qname,question.qtype) == JS_ERROR)
+            harderror(L_QERROR);
         show_esc_stdout(question.qname);
-	printf("\n");
+        printf("\n");
         place += count;
         }
 
@@ -643,14 +643,14 @@ int csv1_answer(js_string *uindata, int *place, js_string *query) {
                L_DOT,*(uindata->string + *place + 3));
         }
     else if(rr_hdr.type == RR_TXT) {
-        printf("|"); 
+        printf("|");
         read_txt(uindata,mx.exchange,*place);
         escape_stdout(mx.exchange);
         printf("\n");
         }
     else {
         printf("|\n");
-	}
+        }
 
     *place += rr_hdr.rdlength; /* To do: read the RD data itself for
                                   all MaraDNS supported RRs */
