@@ -57,7 +57,7 @@ int csv2_answer(js_string *uindata, int *place, js_string *query);
    parse/Csv2_functions.h */
 extern int escape_stdout_csv2(js_string *js);
 
-int verbose_mode = 0; /* Whether to have short or verbose output; 
+int verbose_mode = 0; /* Whether to have short or verbose output;
                          1: verbose output; any other value: short output */
 int timeout = 21;
 
@@ -75,12 +75,12 @@ int escape_stdout(js_string *js) {
 
     while(counter < js->unit_count) {
         this = *(js->string + counter);
-	if(this < 32 || this > 126) 
-	    printf("\\%03o",this);
-        else if(this == '\\') 
-	    printf("\\%c",this);
+        if(this < 32 || this > 126)
+            printf("\\%03o",this);
+        else if(this == '\\')
+            printf("\\%c",this);
         else
-	    printf("%c",this);
+            printf("%c",this);
         counter++;
         }
     return 1;
@@ -107,28 +107,28 @@ u_int16_t gen_id(char *hostname) {
 
     /* Initialize the keys, including the "binKey" (is this used?) */
     memset(r_binKey,'0',16);
-    mc1 = "ñ";
+    mc1 = "";
     mc2 = mc1;
-    /* Set the crypto key to 'ññññññññññññññññ' (UTF-8 encoding) */
+    /* Set the crypto key to '' (UTF-8 encoding) */
     for(counter = 0; counter < 16; counter++) {
         *(crypto_key + counter) = *mc2;
-	mc2++;
-	if(*mc2 == 0) 
-	   mc2 = mc1;
+        mc2++;
+        if(*mc2 == 0)
+           mc2 = mc1;
         }
-    /*memset(crypto_key,'ñ',16);*/
+    /*memset(crypto_key,'',16);*/
     /* Make the first 16 characters of the hostname the key (padded by the
-       ñ character--do you see a n~ there?) */
+        character--do you see a n~ there?) */
     strncpy((char *)crypto_key,hostname,16);
-    /* Set the plaintext block to 'ññññññññññññññññ' (UTF-8 encoding) */
+    /* Set the plaintext block to '' (UTF-8 encoding) */
     mc2 = mc1;
     for(counter = 0; counter < 16; counter++) {
         *(r_inBlock + counter) = *mc2;
-	mc2++;
-	if(*mc2 == 0) 
-	   mc2 = mc1;
+        mc2++;
+        if(*mc2 == 0)
+           mc2 = mc1;
         }
-    /*memset(r_inBlock,'ñ',16);*/
+    /*memset(r_inBlock,'',16);*/
     /* If the hostname is longer than 16 characters, make the plaintext
        the longer part of the hostname */
     if(strlen(hostname) > 16)
@@ -172,7 +172,7 @@ int main(int argc, char **argv) {
     int id;
     int attempts = 10;
     int desired_rr = -1; /* This is used to determine what RR type the
-			    user desires */
+                            user desires */
     char *temp;
 
 #ifdef MINGW32
@@ -195,13 +195,13 @@ int main(int argc, char **argv) {
 
     /* See if we should allow a user defined timeout or not */
     timeout = 31;
-    if(argc >= 4 + nrd && *argv[1 + nrd] == '-' && *(argv[1 + nrd] + 1) == 
+    if(argc >= 4 + nrd && *argv[1 + nrd] == '-' && *(argv[1 + nrd] + 1) ==
        't') {
          timeout = atoi(argv[2 + nrd]);
-	 verbose_mode = 2;
-	 }
+         verbose_mode = 2;
+         }
 
-    if(timeout < 1) 
+    if(timeout < 1)
         harderror(L_INVALID_TIMEOUT);
 
     /* Determine what IP address to connect to */
@@ -259,25 +259,25 @@ int main(int argc, char **argv) {
      * 40:t1.example.com., where 40 is the numeric rrtype */
     temp = argv[1 + verbose_mode + nrd];
     if(temp == 0) {
-	    printf("Wrong number of arguments to askmara\n");
-	    exit(43);
+            printf("Wrong number of arguments to askmara\n");
+            exit(43);
     }
     if(*temp >= '0' && *temp <= '9') {
-	int td = 0;
-	desired_rr = 0;
-	for(td = 0; td < 7; td++) {
-		if(*temp < '0' || *temp > '9') {
-			break;
-		}
-		desired_rr *= 10;
-		desired_rr += *temp - '0';
-		temp++;
-	}
-	if(*temp != ':') {
-		printf("Invalid numeric rtype\n");
-		exit(44);
-	}
-	*temp = 'A';
+        int td = 0;
+        desired_rr = 0;
+        for(td = 0; td < 7; td++) {
+                if(*temp < '0' || *temp > '9') {
+                        break;
+                }
+                desired_rr *= 10;
+                desired_rr += *temp - '0';
+                temp++;
+        }
+        if(*temp != ':') {
+                printf("Invalid numeric rtype\n");
+                exit(44);
+        }
+        *temp = 'A';
     }
 
     if(js_qstr2js(question.qname,temp) == JS_ERROR)
@@ -298,7 +298,7 @@ int main(int argc, char **argv) {
     question.qtype = place;
     /* 40:name.example.com. style queries */
     if(desired_rr >= 0 && desired_rr <= 65535) {
-	    question.qtype = desired_rr;
+            question.qtype = desired_rr;
     }
 
     /* Make a string containing the RAW UDP query */
@@ -331,16 +331,16 @@ int main(int argc, char **argv) {
 
         /* Get the ID from the remote response */
         if(count > 2) {
-	   id = (*(indata->string) << 8) | *(indata->string + 1);
-	   }
+           id = (*(indata->string) << 8) | *(indata->string + 1);
+           }
         else {
-	   id = header.id + 1;
-	   }
+           id = header.id + 1;
+           }
 
         attempts--;
 
-	/* If the id doesn't match, get a reply again */
-	} while(id != header.id && attempts > 0); 
+        /* If the id doesn't match, get a reply again */
+        } while(id != header.id && attempts > 0);
 
     decomp_init(0);
     decompress_data(indata,uindata);
@@ -519,7 +519,7 @@ int out_answer(js_string *uindata,int *place) {
 
         *place += rr_hdr.rdlength; /* To do: read the RD data itself for
                                       all MaraDNS supported RRs */
-	return 0;
+        return 0;
         }
 
 /* csv2-compatible form of askmara output
@@ -543,32 +543,32 @@ int csv2_compatible_output(js_string *uindata, js_string *query) {
         harderror(L_INHEADER_CONV); /* Problem converting inheader */
 
     if(header.tc == 1) {
-	printf("# Remote server said: TRUNCATED\n");
+        printf("# Remote server said: TRUNCATED\n");
     }
 
     /* If not 0, show them the rcode from the remote server */
     switch(header.rcode) {
-	case 1:
-		printf("# Remote server said: FORMAT ERROR\n");
-		break;
-	case 2:
-		printf("# Remote server said: SERVER FAILURE\n");
-		break;
-	case 3:
-		printf("# Remote server said: NAME ERROR\n");
-		break;
-	case 4:
-		printf("# Remote server said: NOT IMPLEMENTED\n");
-		break;
-	case 5:
-		printf("# Remote server said: REFUSED\n");
-		break;
-	case 0:
-		break;
-	default:
-		printf("# Non-RFC1035 RCODE %d sent from remote server\n",
+        case 1:
+                printf("# Remote server said: FORMAT ERROR\n");
+                break;
+        case 2:
+                printf("# Remote server said: SERVER FAILURE\n");
+                break;
+        case 3:
+                printf("# Remote server said: NAME ERROR\n");
+                break;
+        case 4:
+                printf("# Remote server said: NOT IMPLEMENTED\n");
+                break;
+        case 5:
+                printf("# Remote server said: REFUSED\n");
+                break;
+        case 0:
+                break;
+        default:
+                printf("# Non-RFC1035 RCODE %d sent from remote server\n",
                        header.rcode);
-	}
+        }
 
     /* Move past the questions */
     place = 12;
@@ -577,10 +577,10 @@ int csv2_compatible_output(js_string *uindata, js_string *query) {
         if(count < 0) /* Error handling */
             harderror(L_QERROR); /* Error reading question */
         printf("# Question: ");
-	if(hname_translate(question.qname,question.qtype) == JS_ERROR) 
-	    harderror(L_QERROR);
+        if(hname_translate(question.qname,question.qtype) == JS_ERROR)
+            harderror(L_QERROR);
         show_esc_stdout(question.qname);
-	printf("\n");
+        printf("\n");
         place += count;
         }
 
@@ -656,7 +656,7 @@ int csv2_answer(js_string *uindata, int *place, js_string *query) {
     hname_translate(rr_hdr.name,rr_hdr.type);
     t = js_create(256,1);
     if(js_copy(rr_hdr.name,t) == JS_ERROR) {
-	    harderror("Couldn't copy hostname");
+            harderror("Couldn't copy hostname");
     }
     t->string++;
     t->unit_count--;
@@ -686,7 +686,7 @@ int csv2_answer(js_string *uindata, int *place, js_string *query) {
                          (*(uindata->string + *place + 1) & 0xff);
         read_ns(uindata,mx.exchange,*place + 2);
         printf(" +%u mx %d",rr_hdr.ttl,mx.preference); /* MX pref. */
-        hname_translate(mx.exchange,RR_MAGIC_SPACE); /* Makes the char a 
+        hname_translate(mx.exchange,RR_MAGIC_SPACE); /* Makes the char a
                                                       * space */
         escape_stdout(mx.exchange);
         printf("\n");
@@ -695,16 +695,16 @@ int csv2_answer(js_string *uindata, int *place, js_string *query) {
             rr_hdr.type == RR_PTR) {
         printf(" +%u",rr_hdr.ttl);
         switch(rr_hdr.type) {
-		case RR_NS:
-			printf(" ns");
-			break;
-		case RR_CNAME:
-			printf(" cname");
-			break;
-		case RR_PTR:
-			printf(" ptr");
-			break;
-		}
+                case RR_NS:
+                        printf(" ns");
+                        break;
+                case RR_CNAME:
+                        printf(" cname");
+                        break;
+                case RR_PTR:
+                        printf(" ptr");
+                        break;
+                }
         read_ns(uindata,mx.exchange,*place);
         hname_translate(mx.exchange,RR_MAGIC_SPACE); /* First char is space */
         escape_stdout(mx.exchange);
@@ -715,18 +715,18 @@ int csv2_answer(js_string *uindata, int *place, js_string *query) {
             return JS_ERROR;
         /* Display the IP of the data */
         printf(" +%u a %d%s%d%s%d%s%d\n", rr_hdr.ttl,
-			*(uindata->string + *place),
+                        *(uindata->string + *place),
                L_DOT,*(uindata->string + *place + 1),
                L_DOT,*(uindata->string + *place + 2),
                L_DOT,*(uindata->string + *place + 3));
         }
     else if(rr_hdr.type == RR_TXT) {
         int len,p;
-	len = rr_hdr.rdlength;
-	p = *place;
-        printf(" +%u txt ",rr_hdr.ttl); 
-	/* XXX: This doesn't correctly handle multi-chunked TXT data */
-	while(len > 0) {
+        len = rr_hdr.rdlength;
+        p = *place;
+        printf(" +%u txt ",rr_hdr.ttl);
+        /* XXX: This doesn't correctly handle multi-chunked TXT data */
+        while(len > 0) {
             int q;
             q = read_txt(uindata,mx.exchange,p);
             if(q < 0) {
@@ -735,9 +735,9 @@ int csv2_answer(js_string *uindata, int *place, js_string *query) {
                 }
             q++;
             escape_stdout_csv2(mx.exchange);
-	    len -= q;
+            len -= q;
             p += q;
-	    if(len > 0) { 
+            if(len > 0) {
                 printf(";");
                 }
             else {
@@ -746,18 +746,18 @@ int csv2_answer(js_string *uindata, int *place, js_string *query) {
             }
          }
     else {
-	printf(" +%u raw %d ",rr_hdr.ttl,rr_hdr.type);
+        printf(" +%u raw %d ",rr_hdr.ttl,rr_hdr.type);
         if(js_substr(uindata,mx.exchange,*place,rr_hdr.rdlength) == JS_ERROR) {
-		printf("Problem copying string over\n");
-		exit(55);
-	}
+                printf("Problem copying string over\n");
+                exit(55);
+        }
         escape_stdout_csv2(mx.exchange);
         printf(" \n");
-	}
+        }
 
     *place += rr_hdr.rdlength; /* To do: read the RD data itself for
                                   all MaraDNS supported RRs */
     return 0;
     }
-    
+
 
